Gramacy Lee Function test function
Functions
- gramacy_
lee_ function - Gramacy & Lee (2012) Function - Alternative test function with noise This is a variant used specifically for Gaussian process testing Global minimum varies due to noise component Bounds: x in [0, 1]